import soundbox
import numpy as np
import scipy.signal as sig
import sys

if len(sys.argv) != 2:
    print(f"""Utilisation: {sys.argv[0]} [source]

Détermine les notes jouées dans le fichier [source] en utilisant
la transformation de Fourier.""")
    sys.exit(1)

source_file = sys.argv[1]

# Calcul du FFT
signal = soundbox.load_signal(source_file)
freq_scale = soundbox.samp_rate / len(signal)

vecs = np.fft.fft(signal)[:soundbox.samp_rate // 2]
values = np.absolute(vecs) / np.max(np.absolute(vecs))
freq = np.arange(len(values))

# Calcul de la fenêtre des fréquences intéressantes
high_enough = np.where(values >= 0.01)
left = high_enough[0][0]
right = high_enough[0][-1]

freq = freq[left:right]
values = values[left:right]

# Recherche des pics
peaks, _ = sig.find_peaks(values, height=0.1, distance=10 / freq_scale)
print(list(map(soundbox.freq_note, freq[peaks] * freq_scale)))
